@@ -4,14 +4,19 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <glib.h>
 #include <string.h>
 #include <ctype.h>
+#include <limits.h>
+#include <liboil/liboil-stdint.h>
 #include <liboil/liboil.h>
+#include <liboil/liboildebug.h>
+#include <stdarg.h>
 
 #include "jpeg_internal.h"
 
 
+#define MAX(a,b) ((a)>(b) ? (a) : (b))
+
 
 #define JPEG_MARKER_STUFFED		0x00
 #define JPEG_MARKER_TEM			0x01
@@ -90,13 +95,13 @@ static struct jpeg_marker_struct jpeg_markers[] = {
   {0xc6, NULL, "differential progressive DCT"},
   {0xc7, NULL, "differential lossless (sequential)"},
   {0xc8, NULL, "reserved"},
-  {0xc9, NULL, "extended sequential DCT"},
-  {0xca, NULL, "progressive DCT"},
-  {0xcb, NULL, "lossless (sequential)"},
+  {0xc9, NULL, "extended sequential DCT (arith)"},
+  {0xca, NULL, "progressive DCT (arith)"},
+  {0xcb, NULL, "lossless (sequential) (arith)"},
   {0xcc, NULL, "define arithmetic coding conditioning(s)"},
-  {0xcd, NULL, "differential sequential DCT"},
-  {0xce, NULL, "differential progressive DCT"},
-  {0xcf, NULL, "differential lossless (sequential)"},
+  {0xcd, NULL, "differential sequential DCT (arith)"},
+  {0xce, NULL, "differential progressive DCT (arith)"},
+  {0xcf, NULL, "differential lossless (sequential) (arith)"},
 
   {0xd0, jpeg_decoder_restart, "restart0", JPEG_ENTROPY_SEGMENT},
   {0xd1, jpeg_decoder_restart, "restart1", JPEG_ENTROPY_SEGMENT},
@@ -217,7 +222,7 @@ jpeg_decoder_sof_baseline_dct (JpegDecoder * dec, bits_t * bits)
   int rowstride;
   int max_h_oversample = 0, max_v_oversample = 0;
 
-  JPEG_DEBUG (0, "start of frame (baseline DCT)\n");
+  OIL_DEBUG ("start of frame (baseline DCT)");
 
   length = get_be_u16 (bits);
   bits->end = bits->ptr + length - 2;
@@ -227,8 +232,8 @@ jpeg_decoder_sof_baseline_dct (JpegDecoder * dec, bits_t * bits)
   dec->width = get_be_u16 (bits);
   dec->n_components = get_u8 (bits);
 
-  JPEG_DEBUG (0,
-      "frame_length=%d depth=%d height=%d width=%d n_components=%d\n", length,
+  OIL_DEBUG (
+      "frame_length=%d depth=%d height=%d width=%d n_components=%d", length,
       dec->depth, dec->height, dec->width, dec->n_components);
 
   for (i = 0; i < dec->n_components; i++) {
@@ -237,8 +242,8 @@ jpeg_decoder_sof_baseline_dct (JpegDecoder * dec, bits_t * bits)
     dec->components[i].v_oversample = getbits (bits, 4);
     dec->components[i].quant_table = get_u8 (bits);
 
-    JPEG_DEBUG (0,
-        "[%d] id=%d h_oversample=%d v_oversample=%d quant_table=%d\n", i,
+    OIL_DEBUG (
+        "[%d] id=%d h_oversample=%d v_oversample=%d quant_table=%d", i,
         dec->components[i].id, dec->components[i].h_oversample,
         dec->components[i].v_oversample, dec->components[i].quant_table);
 
@@ -261,11 +266,11 @@ jpeg_decoder_sof_baseline_dct (JpegDecoder * dec, bits_t * bits)
         (dec->height_blocks * 8 * max_v_oversample /
         dec->components[i].v_subsample);
     dec->components[i].rowstride = rowstride;
-    dec->components[i].image = g_malloc (image_size);
+    dec->components[i].image = malloc (image_size);
   }
 
   if (bits->end != bits->ptr)
-    JPEG_DEBUG (0, "endptr != bits\n");
+    OIL_DEBUG ("endptr != bits");
 
   return length;
 }
@@ -279,7 +284,7 @@ jpeg_decoder_define_quant_table (JpegDecoder * dec, bits_t * bits)
   int i;
   short *q;
 
-  JPEG_DEBUG (0, "define quantization table\n");
+  OIL_DEBUG ("define quantization table");
 
   length = get_be_u16 (bits);
   bits->end = bits->ptr + length - 2;
@@ -299,9 +304,9 @@ jpeg_decoder_define_quant_table (JpegDecoder * dec, bits_t * bits)
       }
     }
 
-    JPEG_DEBUG (0, "quant table index %d:\n", tq);
+    OIL_DEBUG ("quant table index %d:", tq);
     for (i = 0; i < 8; i++) {
-      JPEG_DEBUG (0, "%3d %3d %3d %3d %3d %3d %3d %3d\n",
+      OIL_DEBUG ("%3d %3d %3d %3d %3d %3d %3d %3d",
           q[0], q[1], q[2], q[3], q[4], q[5], q[6], q[7]);
       q += 8;
     }
@@ -325,7 +330,7 @@ generate_code_table (int *huffsize)
   k = 0;
   for (i = 0; i < 16; i++) {
     for (j = 0; j < huffsize[i]; j++) {
-      JPEG_DEBUG (0, "huffcode[%d] = %s\n", k,
+      OIL_DEBUG ("huffcode[%d] = %s", k,
           sprintbits (str, code >> (15 - i), i + 1));
       code++;
       k++;
@@ -372,7 +377,7 @@ huffman_table_new_jpeg (bits_t * bits)
      * number of bits we think it is.  This is only triggered
      * for bad huffsize[] arrays. */
     if (symbol >= (1 << (i + 1))) {
-      JPEG_DEBUG (0, "bad huffsize[] array\n");
+      OIL_DEBUG ("bad huffsize[] array");
       return NULL;
     }
 
@@ -392,7 +397,7 @@ jpeg_decoder_define_huffman_table (JpegDecoder * dec, bits_t * bits)
   int th;
   HuffmanTable *hufftab;
 
-  JPEG_DEBUG (0, "define huffman table\n");
+  OIL_DEBUG ("define huffman table");
 
   length = get_be_u16 (bits);
   bits->end = bits->ptr + length - 2;
@@ -401,8 +406,8 @@ jpeg_decoder_define_huffman_table (JpegDecoder * dec, bits_t * bits)
     tc = getbits (bits, 4);
     th = getbits (bits, 4);
 
-    JPEG_DEBUG (0, "huff table index %d:\n", th);
-    JPEG_DEBUG (0, "type %d (%s)\n", tc, tc ? "ac" : "dc");
+    OIL_DEBUG ("huff table index %d:", th);
+    OIL_DEBUG ("type %d (%s)", tc, tc ? "ac" : "dc");
 
     hufftab = huffman_table_new_jpeg (bits);
     if (tc) {
@@ -436,7 +441,7 @@ dumpbits (bits_t * bits)
     for (j = 0; j < 8; j++) {
       s[j + 24] = (isprint (p[j])) ? p[j] : '.';
     }
-    JPEG_DEBUG (0, "%s\n", s);
+    OIL_DEBUG ("%s", s);
     p += 8;
   }
 
@@ -451,7 +456,7 @@ jpeg_decoder_find_component_by_id (JpegDecoder * dec, int id)
     if (dec->components[i].id == id)
       return i;
   }
-  JPEG_DEBUG (0, "undefined component id %d\n", id);
+  OIL_DEBUG ("undefined component id %d", id);
   return 0;
 }
 
@@ -468,11 +473,11 @@ jpeg_decoder_sos (JpegDecoder * dec, bits_t * bits)
   int approx_low;
   int n;
 
-  JPEG_DEBUG (0, "start of scan\n");
+  OIL_DEBUG ("start of scan");
 
   length = get_be_u16 (bits);
   bits->end = bits->ptr + length - 2;
-  JPEG_DEBUG (0, "length=%d\n", length);
+  OIL_DEBUG ("length=%d", length);
 
   n_components = get_u8 (bits);
   n = 0;
@@ -517,17 +522,17 @@ jpeg_decoder_sos (JpegDecoder * dec, bits_t * bits)
 
     syncbits (bits);
 
-    JPEG_DEBUG (0, "component %d: index=%d dc_table=%d ac_table=%d n=%d\n",
+    OIL_DEBUG ("component %d: index=%d dc_table=%d ac_table=%d n=%d",
         component_id, index, dc_table, ac_table, n);
   }
   dec->scan_list_length = n;
 
   spectral_start = get_u8 (bits);
   spectral_end = get_u8 (bits);
-  JPEG_DEBUG (0, "spectral range [%d,%d]\n", spectral_start, spectral_end);
+  OIL_DEBUG ("spectral range [%d,%d]", spectral_start, spectral_end);
   approx_high = getbits (bits, 4);
   approx_low = getbits (bits, 4);
-  JPEG_DEBUG (0, "approx range [%d,%d]\n", approx_low, approx_high);
+  OIL_DEBUG ("approx range [%d,%d]", approx_low, approx_high);
   syncbits (bits);
 
   dec->x = 0;
@@ -535,7 +540,7 @@ jpeg_decoder_sos (JpegDecoder * dec, bits_t * bits)
   dec->dc[0] = dec->dc[1] = dec->dc[2] = dec->dc[3] = 128 * 8;
 
   if (bits->end != bits->ptr)
-    JPEG_DEBUG (0, "endptr != bits\n");
+    OIL_DEBUG ("endptr != bits");
 
   return length;
 }
@@ -545,10 +550,10 @@ jpeg_decoder_application0 (JpegDecoder * dec, bits_t * bits)
 {
   int length;
 
-  JPEG_DEBUG (0, "app0\n");
+  OIL_DEBUG ("app0");
 
   length = get_be_u16 (bits);
-  JPEG_DEBUG (0, "length=%d\n", length);
+  OIL_DEBUG ("length=%d", length);
 
   if (memcmp (bits->ptr, "JFIF", 4) == 0 && bits->ptr[4] == 0) {
     int version;
@@ -558,7 +563,7 @@ jpeg_decoder_application0 (JpegDecoder * dec, bits_t * bits)
     int x_thumbnail;
     int y_thumbnail;
 
-    JPEG_DEBUG (0, "JFIF\n");
+    OIL_DEBUG ("JFIF");
     bits->ptr += 5;
 
     version = get_be_u16 (bits);
@@ -568,17 +573,17 @@ jpeg_decoder_application0 (JpegDecoder * dec, bits_t * bits)
     x_thumbnail = get_u8 (bits);
     y_thumbnail = get_u8 (bits);
 
-    JPEG_DEBUG (0, "version = %04x\n", version);
-    JPEG_DEBUG (0, "units = %d\n", units);
-    JPEG_DEBUG (0, "x_density = %d\n", x_density);
-    JPEG_DEBUG (0, "y_density = %d\n", y_density);
-    JPEG_DEBUG (0, "x_thumbnail = %d\n", x_thumbnail);
-    JPEG_DEBUG (0, "y_thumbnail = %d\n", y_thumbnail);
+    OIL_DEBUG ("version = %04x", version);
+    OIL_DEBUG ("units = %d", units);
+    OIL_DEBUG ("x_density = %d", x_density);
+    OIL_DEBUG ("y_density = %d", y_density);
+    OIL_DEBUG ("x_thumbnail = %d", x_thumbnail);
+    OIL_DEBUG ("y_thumbnail = %d", y_thumbnail);
 
   }
 
   if (memcmp (bits->ptr, "JFXX", 4) == 0 && bits->ptr[4] == 0) {
-    JPEG_DEBUG (0, "JFIF extension (not handled)\n");
+    OIL_DEBUG ("JFIF extension (not handled)");
     bits->ptr += length - 2;
   }
 
@@ -590,12 +595,12 @@ jpeg_decoder_application_misc (JpegDecoder * dec, bits_t * bits)
 {
   int length;
 
-  JPEG_DEBUG (0, "appX\n");
+  OIL_DEBUG ("appX");
 
   length = get_be_u16 (bits);
-  JPEG_DEBUG (0, "length=%d\n", length);
+  OIL_DEBUG ("length=%d", length);
 
-  JPEG_DEBUG (0, "JPEG application tag X ignored\n");
+  OIL_DEBUG ("JPEG application tag X ignored");
   dumpbits (bits);
 
   bits->ptr += length - 2;
@@ -608,10 +613,10 @@ jpeg_decoder_comment (JpegDecoder * dec, bits_t * bits)
 {
   int length;
 
-  JPEG_DEBUG (0, "comment\n");
+  OIL_DEBUG ("comment");
 
   length = get_be_u16 (bits);
-  JPEG_DEBUG (0, "length=%d\n", length);
+  OIL_DEBUG ("length=%d", length);
 
   dumpbits (bits);
 
@@ -625,13 +630,13 @@ jpeg_decoder_restart_interval (JpegDecoder * dec, bits_t * bits)
 {
   int length;
 
-  JPEG_DEBUG (0, "comment\n");
+  OIL_DEBUG ("comment");
 
   length = get_be_u16 (bits);
-  JPEG_DEBUG (0, "length=%d\n", length);
+  OIL_DEBUG ("length=%d", length);
 
   dec->restart_interval = get_be_u16 (bits);
-  JPEG_DEBUG (0, "restart_interval=%d\n", dec->restart_interval);
+  OIL_DEBUG ("restart_interval=%d", dec->restart_interval);
 
   return length;
 }
@@ -639,7 +644,7 @@ jpeg_decoder_restart_interval (JpegDecoder * dec, bits_t * bits)
 int
 jpeg_decoder_restart (JpegDecoder * dec, bits_t * bits)
 {
-  JPEG_DEBUG (0, "restart\n");
+  OIL_DEBUG ("restart");
 
   return 0;
 }
@@ -667,11 +672,11 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
     }
     len++;
   }
-  JPEG_DEBUG (0, "entropy length = %d\n", len);
+  OIL_DEBUG ("entropy length = %d", len);
 
   /* we allocate extra space, since the getbits() code can
    * potentially read past the end of the buffer */
-  newptr = g_malloc (len + 2);
+  newptr = malloc (len + 2);
   for (i = 0; i < len; i++) {
     newptr[j] = bits->ptr[i];
     j++;
@@ -691,8 +696,7 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
   x = dec->x;
   y = dec->y;
   n = dec->restart_interval;
-  if (n == 0)
-    n = G_MAXINT;
+  if (n == 0) n = INT_MAX;
   while (n-- > 0) {
     for (i = 0; i < dec->scan_list_length; i++) {
       int dc_table_index;
@@ -701,7 +705,7 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
       unsigned char *ptr;
       int component_index;
 
-      JPEG_DEBUG (3, "%d,%d: component=%d dc_table=%d ac_table=%d\n",
+      OIL_DEBUG ("%d,%d: component=%d dc_table=%d ac_table=%d",
           x, y,
           dec->scan_list[i].component_index,
           dec->scan_list[i].dc_table, dec->scan_list[i].ac_table);
@@ -715,7 +719,7 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
           dec->dc_huff_table[dc_table_index],
           dec->ac_huff_table[ac_table_index], bits2);
       if (ret < 0) {
-        JPEG_DEBUG (0, "%d,%d: component=%d dc_table=%d ac_table=%d\n",
+        OIL_DEBUG ("%d,%d: component=%d dc_table=%d ac_table=%d",
             x, y,
             dec->scan_list[i].component_index,
             dec->scan_list[i].dc_table, dec->scan_list[i].ac_table);
@@ -723,7 +727,7 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
         break;
       }
 
-      JPEG_DEBUG (3, "using quant table %d\n", quant_index);
+      OIL_DEBUG ("using quant table %d", quant_index);
       oil_mult8x8_s16 (block2, block, dec->quant_table[quant_index],
           sizeof (short) * 8, sizeof(short) * 8, sizeof (short) * 8);
       dec->dc[component_index] += block2[0];
@@ -754,7 +758,7 @@ jpeg_decoder_decode_entropy_segment (JpegDecoder * dec, bits_t * bits)
   }
   dec->x = x;
   dec->y = y;
-  g_free (newptr);
+  free (newptr);
 }
 
 
@@ -766,7 +770,8 @@ jpeg_decoder_new (void)
 
   oil_init ();
 
-  dec = g_new0 (JpegDecoder, 1);
+  dec = malloc (sizeof(JpegDecoder));
+  memset (dec, 0, sizeof(JpegDecoder));
 
   huffman_table_load_std_jpeg (dec);
 
@@ -785,13 +790,13 @@ jpeg_decoder_free (JpegDecoder * dec)
 
   for (i = 0; i < JPEG_N_COMPONENTS; i++) {
     if (dec->components[i].image)
-      g_free (dec->components[i].image);
+      free (dec->components[i].image);
   }
 
   if (dec->data)
-    g_free (dec->data);
+    free (dec->data);
 
-  g_free (dec);
+  free (dec);
 }
 
 int
@@ -887,13 +892,13 @@ jpeg_decoder_parse (JpegDecoder * dec)
         x = get_u8 (bits);
         n++;
       }
-      JPEG_DEBUG (0, "lost sync, skipped %d bytes\n", n);
+      OIL_DEBUG ("lost sync, skipped %d bytes", n);
     }
     while (x == 0xff) {
       x = get_u8 (bits);
     }
     tag = x;
-    JPEG_DEBUG (0, "tag %02x\n", tag);
+    OIL_DEBUG ("tag %02x", tag);
 
     b2 = *bits;
 
@@ -902,11 +907,11 @@ jpeg_decoder_parse (JpegDecoder * dec)
         break;
       }
     }
-    JPEG_DEBUG (0, "tag: %s\n", jpeg_markers[i].name);
+    OIL_DEBUG ("tag: %s", jpeg_markers[i].name);
     if (jpeg_markers[i].func) {
       jpeg_markers[i].func (dec, &b2);
     } else {
-      JPEG_DEBUG (0, "unhandled or illegal JPEG marker (0x%02x)\n", tag);
+      OIL_DEBUG ("unhandled or illegal JPEG marker (0x%02x)", tag);
       dumpbits (&b2);
     }
     if (jpeg_markers[i].flags & JPEG_ENTROPY_SEGMENT) {
@@ -920,24 +925,6 @@ jpeg_decoder_parse (JpegDecoder * dec)
 }
 
 
-int jpeg_decoder_verbose_level = -1;
-
-void
-jpeg_debug (int n, const char *format, ...)
-{
-  va_list args;
-
-  if (n > jpeg_decoder_verbose_level)
-    return;
-
-  fflush (stdout);
-  fprintf (stderr, "JPEG_DEBUG: ");
-  va_start (args, format);
-  vfprintf (stderr, format, args);
-  va_end (args);
-}
-
-
 /* misc helper functins */
 
 static char *
@@ -969,3 +956,4 @@ huffman_table_load_std_jpeg (JpegDecoder * dec)
   dec->dc_huff_table[1] = huffman_table_new_jpeg (bits);
   dec->ac_huff_table[1] = huffman_table_new_jpeg (bits);
 }
+
