@@ -2,7 +2,7 @@
 #ifndef _JPEG_DECODER_H_
 #define _JPEG_DECODER_H_
 
-typedef struct jpeg_decoder_struct JpegDecoder;
+typedef struct _JpegDecoder JpegDecoder;
 
 
 JpegDecoder *jpeg_decoder_new(void);
@@ -17,6 +17,8 @@ int jpeg_decoder_get_component_subsampling(JpegDecoder *dec, int id,
 int jpeg_decoder_get_component_ptr(JpegDecoder *dec, int id,
 	unsigned char **image, int *rowstride);
 
+unsigned char *jpeg_decoder_get_argb_image (JpegDecoder *dec);
+
 
 #endif
 
